@@ -19,7 +19,6 @@ OC.L10N.register(
     "Calendar" : "Calendariu",
     "New booking {booking}" : "Reserva nueva «{booking}»",
     "Appointments" : "Cites",
-    "%1$s - %2$s" : "%1$s - %2$s",
     "Confirm" : "Confirmar",
     "Description:" : "Descripción:",
     "Date:" : "Data:",
@@ -284,6 +283,7 @@ OC.L10N.register(
     "Imported {filename}" : "Importóse «{filename}»",
     "This is an event reminder." : "Esto ye un recordatoriu del eventu.",
     "User not found" : "Nun s'atopó l'usuariu",
+    "%1$s - %2$s" : "%1$s - %2$s",
     "Hidden" : "Anubrióse",
     "Calendar name …" : "Nome del calendariu…",
     "CalDAV link copied to clipboard." : "L'enllaz CalDAV copióse nel cartafueyu.",
@@ -299,7 +299,6 @@ OC.L10N.register(
     "Personal availability settings" : "Configuración de la disponibilidá personal",
     "Show keyboard shortcuts" : "Amosar los atayos del tecáu",
     "Error creating Talk room" : "Hebo un error al crear la sala de Talk",
-    "_%n more guest_::_%n more guests_" : ["%n convidáu más","%n convidaos más"],
-    "Keyboard shortcuts" : "Atayos del tecláu"
+    "_%n more guest_::_%n more guests_" : ["%n convidáu más","%n convidaos más"]
 },
 "nplurals=2; plural=(n != 1);");
