@@ -132,12 +132,8 @@ OC.L10N.register(
     "Delete edited event" : "Dileu digwyddiad wedi'i olygu",
     "or" : "neu",
     "No reminder" : "Dim nodyn atgoffa",
-    "CalDAV link copied to clipboard." : "Dolen CalDAV wedi'i chopïo i'r clipfwrdd.",
-    "CalDAV link could not be copied to clipboard." : "Nid oedd modd copïo dolen CalDAV i'r clipfwrdd.",
     "General" : "Cyffredinol",
-    "Copy iOS/macOS CalDAV address" : "Copïo cyfeiriad CalDAV iOS/macOS",
     "Default reminder" : "Nodyn atgoffa rhagosodedig",
-    "Keyboard shortcuts" : "Llwybrau byr bysellfwrdd",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} munud","{duration} funud","{duration} munud","{duration} munud"],
     "0 minutes" : "0 munud",
     "_{duration} hour_::_{duration} hours_" : ["{duration} awr","{duration} awr","{duration} awr","{duration} awr"],
@@ -226,9 +222,8 @@ OC.L10N.register(
     "Accept" : "Derbyn",
     "Decline" : "Gwrthod",
     "Tentative" : "I'w gadarnhau",
+    "Copied to clipboard" : "Wedi'i gopïo i'r clipfwrdd",
     "No attendees yet" : "Dim mynychwyr eto",
-    "Successfully appended link to talk room to description." : "Llwyddwyd i atodi dolen i'r ystafell siarad i'r disgrifiad.",
-    "Error creating Talk room" : "Gwall wrth greu ystafell Siarad",
     "Attendees" : "Mynychwyr",
     "Remove attendee" : "Dileu mynychwr",
     "Chairperson" : "Cadeirydd",
@@ -412,6 +407,8 @@ OC.L10N.register(
     "can edit" : "yn gallu golygu",
     "Automatic ({detected})" : "Awtomatig ({detected})",
     "Shortcut overview" : "Trosolwg llwybr byr",
+    "CalDAV link copied to clipboard." : "Dolen CalDAV wedi'i chopïo i'r clipfwrdd.",
+    "CalDAV link could not be copied to clipboard." : "Nid oedd modd copïo dolen CalDAV i'r clipfwrdd.",
     "Enable birthday calendar" : "Galluogi calendr pen-blwydd",
     "Show tasks in calendar" : "Dangos tasgau yn y calendr",
     "Enable simplified editor" : "Galluogi golygydd symlach",
@@ -419,8 +416,11 @@ OC.L10N.register(
     "Show week numbers" : "Dangos rhifau wythnosau",
     "Time increments" : "Cynyddiadau amser",
     "Copy primary CalDAV address" : "Copïo prig gyfeiriad CalDAV",
+    "Copy iOS/macOS CalDAV address" : "Copïo cyfeiriad CalDAV iOS/macOS",
     "Personal availability settings" : "Gosodiadau argaeledd personol",
     "Show keyboard shortcuts" : "Dangos llwybrau byr bysellfwrdd",
+    "Successfully appended link to talk room to description." : "Llwyddwyd i atodi dolen i'r ystafell siarad i'r disgrifiad.",
+    "Error creating Talk room" : "Gwall wrth greu ystafell Siarad",
     "The visibility of this event in shared calendars." : "Gwelededd y digwyddiad hwn mewn calendrau a rennir."
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
