@@ -91,6 +91,7 @@ OC.L10N.register(
     "Accept" : "Akcepti",
     "Decline" : "Malakcepti",
     "Tentative" : "Nekonfirmita",
+    "Copied to clipboard" : "Kopiita en la tondejon",
     "Attendees" : "Ĉeestontoj",
     "Remove group" : "Forigi grupon",
     "Required participant" : "Bezonata partoprenanto",
@@ -149,7 +150,6 @@ OC.L10N.register(
     "Enable simplified editor" : "Ebligi simpligitan redaktilon",
     "Show weekends" : "Montri semajnfinojn",
     "Show week numbers" : "Montri numerojn de semajno",
-    "Show keyboard shortcuts" : "Montri klavarajn ŝparvojojn",
-    "Keyboard shortcuts" : "Fulmoklavoj"
+    "Show keyboard shortcuts" : "Montri klavarajn ŝparvojojn"
 },
 "nplurals=2; plural=(n != 1);");
