@@ -22,7 +22,6 @@ OC.L10N.register(
     "Appointments" : "Citas",
     "Schedule appointment \"%s\"" : "Programar cita \"%s\"",
     "Schedule an appointment" : "Programar una cita",
-    "%1$s - %2$s" : "%1$s - %2$s",
     "Prepare for %s" : "Preparar para %s",
     "Follow up for %s" : "Hacer seguimiento de %s",
     "Your appointment \"%s\" with %s needs confirmation" : "Tu cita \"%s\" con %s necesita confirmación",
@@ -61,6 +60,7 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "No se pudo copiar el enlace de la cita al portapapeles",
     "Preview" : "Previsualizar",
     "Copy link" : "Copiar liga",
+    "Duplicate" : "Duplicar",
     "Edit" : "Editar",
     "Delete" : "Borrar",
     "Create new" : "Crear nuevo",
@@ -227,6 +227,7 @@ OC.L10N.register(
     "Your email address" : "Tu dirección de correo electrónico",
     "Please share anything that will help prepare for our meeting" : "Por favor, comparte cualquier información que ayude a prepararnos para nuestra reunión",
     "Could not book the appointment. Please try again later or contact the organizer." : "No se pudo reservar la cita. Inténtalo de nuevo más tarde o contacta al organizador.",
+    "Back" : "Regresar",
     "Select conversation" : "Seleccionar conversación",
     "on" : "el",
     "at" : "a las",
@@ -286,6 +287,7 @@ OC.L10N.register(
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
     "Tentative" : "Tentativo",
+    "Copied to clipboard" : "Copiado al portapapeles",
     "No attendees yet" : "Aún no hay asistentes",
     "Attendees" : "Asistentes",
     "Remove group" : "Eliminar grupo",
@@ -384,7 +386,6 @@ OC.L10N.register(
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "No se encontró tu zona horaria configurada ({timezoneId}). Se usará UTC.\n      Por favor, cambia tu zona horaria en la configuración y reporta este problema.",
     "Edit event" : "Editar evento",
     "Event does not exist" : "El evento no existe",
-    "Duplicate" : "Duplicar",
     "Delete this occurrence" : "Eliminar esta ocurrencia",
     "Delete this and all future" : "Eliminar esta y todas las siguientes",
     "All day" : "Todo el día",
@@ -488,6 +489,7 @@ OC.L10N.register(
     "This is an event reminder." : "Esto es un recordatorio de evento.",
     "Appointment not found" : "Cita no encontrada",
     "User not found" : "No se encontró el usuario",
+    "%1$s - %2$s" : "%1$s - %2$s",
     "Hidden" : "Oculto",
     "can edit" : "puede editar",
     "Calendar name …" : "Nombre del calendario …",
@@ -509,7 +511,6 @@ OC.L10N.register(
     "Show keyboard shortcuts" : "Mostrar accesos directos de teclado",
     "Successfully appended link to talk room to description." : "Enlace a la sala de Talk se agregó correctamente a la descripción.",
     "Error creating Talk room" : "Error al crear la sala de Talk",
-    "The visibility of this event in shared calendars." : "La visibilidad de este evento en calendarios compartidos.",
-    "Keyboard shortcuts" : "Atajos del teclado"
+    "The visibility of this event in shared calendars." : "La visibilidad de este evento en calendarios compartidos."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
