@@ -22,7 +22,6 @@ OC.L10N.register(
     "Appointments" : "Citas",
     "Schedule appointment \"%s\"" : "Programar cita \"%s\"",
     "Schedule an appointment" : "Programar una cita",
-    "%1$s - %2$s" : "%1$s - %2$s",
     "Prepare for %s" : "Preparación para %s",
     "Follow up for %s" : "Seguimiento para %s",
     "Your appointment \"%s\" with %s needs confirmation" : "Su cita \"%s\" con %s necesita confirmación",
@@ -63,6 +62,7 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "No se pudo copiar el enlace de la cita al portapapeles",
     "Preview" : "Previsualizar",
     "Copy link" : "Copiar liga",
+    "Duplicate" : "Duplicado",
     "Edit" : "Editar",
     "Delete" : "Borrar",
     "Appointment schedules" : "Cronograma de citas",
@@ -208,6 +208,7 @@ OC.L10N.register(
     "Create appointment schedule" : "Crear cronograma de citas",
     "Edit appointment schedule" : "Editar cronograma de citas",
     "Update" : "Actualizar",
+    "(copy)" : "(copiar)",
     "Appointment name" : "Nombre de la cita",
     "Location" : "Ubicación",
     "Create a Talk room" : "Crear una sala de Talk",
@@ -317,6 +318,7 @@ OC.L10N.register(
     "Accept" : "Aceptar",
     "Decline" : "Rechazar",
     "Tentative" : "Tentativo",
+    "Copied to clipboard" : "Copiado al portapapeles",
     "No attendees yet" : "Aún no hay asistentes",
     "Attendees" : "Asistentes",
     "Remove group" : "Eliminar grupo",
@@ -430,7 +432,6 @@ OC.L10N.register(
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "No se encontró la zona horaria configurada ({timezoneId}). Volviendo a UTC.\nPor favor, cambie su zona horaria en la configuración e informe de este problema.",
     "Edit event" : "Editar evento",
     "Event does not exist" : "El evento no existe",
-    "Duplicate" : "Duplicado",
     "Delete this occurrence" : "Eliminar esta ocurrencia",
     "Delete this and all future" : "Eliminar ésta y las futuras",
     "All day" : "Todo el día",
@@ -535,6 +536,7 @@ OC.L10N.register(
     "Error while parsing a PROPFIND error" : "Error al analizar un error PROPFIND",
     "Appointment not found" : "Cita no encontrada",
     "User not found" : "No se encontró el usuario",
+    "%1$s - %2$s" : "%1$s - %2$s",
     "Hidden" : "Oculto",
     "can edit" : "puede editar",
     "Calendar name …" : "Nombre del calendario …",
@@ -560,7 +562,6 @@ OC.L10N.register(
     "Successfully appended link to talk room to description." : "Se ha añadido correctamente el enlace a la sala de conversación a la descripción.",
     "Error creating Talk room" : "Error al crear la sala de Talk",
     "_%n more guest_::_%n more guests_" : ["%n invitado más","%n más invitados","%n más invitados"],
-    "The visibility of this event in shared calendars." : "La visibilidad de este evento en calendarios compartidos.",
-    "Keyboard shortcuts" : "Atajos del teclado"
+    "The visibility of this event in shared calendars." : "La visibilidad de este evento en calendarios compartidos."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
