@@ -22,7 +22,6 @@ OC.L10N.register(
     "Appointments" : "Appointments",
     "Schedule appointment \"%s\"" : "Schedule appointment \"%s\"",
     "Schedule an appointment" : "Schedule an appointment",
-    "%1$s - %2$s" : "%1$s - %2$s",
     "Prepare for %s" : "Prepare for %s",
     "Follow up for %s" : "Follow up for %s",
     "Your appointment \"%s\" with %s needs confirmation" : "Your appointment \"%s\" with %s needs confirmation",
@@ -62,6 +61,7 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "Appointment link could not be copied to clipboard",
     "Preview" : "Preview",
     "Copy link" : "Copy link",
+    "Duplicate" : "Duplicate",
     "Edit" : "Edit",
     "Delete" : "Delete",
     "Create new" : "Create new",
@@ -179,13 +179,9 @@ OC.L10N.register(
     "or" : "or",
     "Calendar settings" : "Calendar settings",
     "No reminder" : "No reminder",
-    "CalDAV link copied to clipboard." : "CalDAV link copied to clipboard.",
-    "CalDAV link could not be copied to clipboard." : "CalDAV link could not be copied to clipboard.",
     "General" : "General",
-    "Copy iOS/macOS CalDAV address" : "Copy iOS/macOS CalDAV address",
     "Editing" : "Editing",
     "Default reminder" : "Default reminder",
-    "Keyboard shortcuts" : "Keyboard shortcuts",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minute","{duration} minutes"],
     "0 minutes" : "0 minutes",
     "_{duration} hour_::_{duration} hours_" : ["{duration} hour","{duration} hours"],
@@ -289,10 +285,8 @@ OC.L10N.register(
     "Accept" : "Accept",
     "Decline" : "Decline",
     "Tentative" : "Tentative",
+    "Copied to clipboard" : "Copied to clipboard",
     "No attendees yet" : "No attendees yet",
-    "Successfully appended link to talk room to location." : "Successfully appended link to talk room to location.",
-    "Successfully appended link to talk room to description." : "Successfully appended link to talk room to description.",
-    "Error creating Talk room" : "Error creating Talk room",
     "Attendees" : "Attendees",
     "Remove group" : "Remove group",
     "Remove attendee" : "Remove attendee",
@@ -399,7 +393,6 @@ OC.L10N.register(
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue.",
     "Event does not exist" : "Event does not exist",
-    "Duplicate" : "Duplicate",
     "Delete this occurrence" : "Delete this occurrence",
     "Delete this and all future" : "Delete this and all future",
     "All day" : "All day",
@@ -503,12 +496,15 @@ OC.L10N.register(
     "This is an event reminder." : "This is an event reminder.",
     "Appointment not found" : "Appointment not found",
     "User not found" : "User not found",
+    "%1$s - %2$s" : "%1$s - %2$s",
     "Hidden" : "Hidden",
     "can edit" : "can edit",
     "Calendar name …" : "Calendar name …",
     "Default attachments location" : "Default attachments location",
     "Automatic ({detected})" : "Automatic ({detected})",
     "Shortcut overview" : "Shortcut overview",
+    "CalDAV link copied to clipboard." : "CalDAV link copied to clipboard.",
+    "CalDAV link could not be copied to clipboard." : "CalDAV link could not be copied to clipboard.",
     "Enable birthday calendar" : "Enable birthday calendar",
     "Show tasks in calendar" : "Show tasks in calendar",
     "Enable simplified editor" : "Enable simplified editor",
@@ -517,8 +513,12 @@ OC.L10N.register(
     "Show week numbers" : "Show week numbers",
     "Time increments" : "Time increments",
     "Copy primary CalDAV address" : "Copy primary CalDAV address",
+    "Copy iOS/macOS CalDAV address" : "Copy iOS/macOS CalDAV address",
     "Personal availability settings" : "Personal availability settings",
     "Show keyboard shortcuts" : "Show keyboard shortcuts",
+    "Successfully appended link to talk room to location." : "Successfully appended link to talk room to location.",
+    "Successfully appended link to talk room to description." : "Successfully appended link to talk room to description.",
+    "Error creating Talk room" : "Error creating Talk room",
     "The visibility of this event in shared calendars." : "The visibility of this event in shared calendars."
 },
 "nplurals=2; plural=(n!=1);");
