@@ -22,7 +22,6 @@ OC.L10N.register(
     "Appointments" : "Состаноци",
     "Schedule appointment \"%s\"" : "Закажан состанок \"%s\"",
     "Schedule an appointment" : "Закажи состанок",
-    "%1$s - %2$s" : "%1$s - %2$s",
     "Prepare for %s" : "Подготовки за %s",
     "Follow up for %s" : "Следи за %s",
     "Your appointment \"%s\" with %s needs confirmation" : "Потребна е потврда за состанокот \"%s\" со %s",
@@ -48,6 +47,7 @@ OC.L10N.register(
     "Dear %s, a proposed meeting has been updated" : "Почитуван/а %s, предложениот состанок е ажуриран",
     "Dear %s, a proposed meeting has been cancelled" : "Почитуван/а %s, предложениот состанок е откажан",
     "Location:" : "Локација:",
+    "%1$s minutes" : "%1$s минути",
     "Duration:" : "Времетраење:",
     "%1$s from %2$s to %3$s" : "%1$s од %2$s до %3$s",
     "Dates:" : "Датуми:",
@@ -73,6 +73,7 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "Линкот за состанокот неможе за се копира во клипборд",
     "Preview" : "Преглед",
     "Copy link" : "Копирај линк",
+    "Duplicate" : "Дуплирај",
     "Edit" : "Уреди",
     "Delete" : "Избриши",
     "Appointment schedules" : "Распоред на состаноци",
@@ -242,6 +243,7 @@ OC.L10N.register(
     "Create appointment schedule" : "Креирај распоред за состаноци",
     "Edit appointment schedule" : "Уреди распоред за состаноци",
     "Update" : "Ажурирај",
+    "(copy)" : "(копирај)",
     "Appointment name" : "Име на состанокот",
     "Location" : "Локација",
     "Create a Talk room" : "Креирај соба за разговор",
@@ -288,11 +290,10 @@ OC.L10N.register(
     "Talk conversation for event" : "Talk разговор за настанот",
     "Error creating Talk conversation" : "Грешка при создавање на Talk разговор.",
     "Select a Talk Room" : "Изберете Talk соба",
-    "Add Talk conversation" : "Додај Talk разговор",
     "Fetching Talk rooms…" : "Се преземаат Talk соби…",
     "No Talk room available" : "Нема достапни Talk соби",
-    "Create public conversation" : "Создај јавен разговор",
     "Select conversation" : "Избери разговор",
+    "Create public conversation" : "Создај јавен разговор",
     "on" : "во",
     "at" : "во",
     "before at" : "пред",
@@ -374,6 +375,7 @@ OC.L10N.register(
     "Accept" : "Прифати",
     "Decline" : "Одбиј",
     "Tentative" : "Пробно",
+    "Copied to clipboard" : "Копирано во клипборд",
     "No attendees yet" : "Сè уште нема присутни",
     "Please add at least one attendee to use the \"Find a time\" feature." : "Додајте барем еден учесник за да ја користите функцијата \"Пронајди време\".",
     "Attendees" : "Присутни",
@@ -507,11 +509,11 @@ OC.L10N.register(
     "Discard event" : "Отфрли настан",
     "Edit event" : "Уреди го настанот",
     "Event does not exist" : "Настанот не постои",
-    "Duplicate" : "Дуплирај",
     "Delete this occurrence" : "Избришете ја оваа можност",
     "Delete this and all future" : "Избришете го овој и сите во иднина",
     "All day" : "Цели денови",
     "Modifications wont get propagated to the organizer and other attendees" : "Измените нема да се применат кај организаторот и другите учесници",
+    "Add Talk conversation" : "Додај Talk разговор",
     "Managing shared access" : "Управување со споделен пристап",
     "Deny access" : "Забрани пристап",
     "Invite" : "Покани",
@@ -667,6 +669,7 @@ OC.L10N.register(
     "Error while parsing a PROPFIND error" : "Грешка при обработка на PROPFIND грешката",
     "Appointment not found" : "Терминот не е пронајден",
     "User not found" : "Корисникот не е пронајден",
+    "%1$s - %2$s" : "%1$s - %2$s",
     "Hidden" : "Сокриен",
     "can edit" : "може да се измени",
     "Calendar name …" : "Име на календар ...",
@@ -693,11 +696,6 @@ OC.L10N.register(
     "Successfully appended link to talk room to description." : "Успешно додаден линк од собата за разговор во описот.",
     "Error creating Talk room" : "Грешка при креирање на соба за разговор",
     "_%n more guest_::_%n more guests_" : ["%n гостин","%n други гости"],
-    "The visibility of this event in shared calendars." : "Видливост на овој настан во споделен календар.",
-    "View options" : "Прегледај опции ",
-    "Limit number of events shown in month view" : "Ограничи го бројот на прикажани настани во месечен преглед",
-    "Time division in day and week view" : "Поделба на време во дневен и неделен преглед",
-    "Enable simple editor" : "Овозможи едноставен уредувач",
-    "Keyboard shortcuts" : "Кратенки преку тастатура"
+    "The visibility of this event in shared calendars." : "Видливост на овој настан во споделен календар."
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
