@@ -22,7 +22,6 @@ OC.L10N.register(
     "Appointments" : "Avtaler",
     "Schedule appointment \"%s\"" : "Registrer avtale \"%s\"",
     "Schedule an appointment" : "Registrer en avtale",
-    "%1$s - %2$s" : "%1$s - %2$s",
     "Prepare for %s" : "Forbered for %s",
     "Follow up for %s" : "Følg opp for %s",
     "Your appointment \"%s\" with %s needs confirmation" : "Avtalen din \"%s\" med %s trenger bekreftelse",
@@ -63,6 +62,7 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "Avtalelenken ble ikke kopiert til utklippstavlen",
     "Preview" : "Forhåndsvis",
     "Copy link" : "Kopier lenke",
+    "Duplicate" : "Duplikat",
     "Edit" : "Rediger",
     "Delete" : "Slett",
     "Create new" : "Opprett ny",
@@ -204,6 +204,7 @@ OC.L10N.register(
     "Public – shown on the profile page" : "Offentlig – vises på profilsiden",
     "Private – only accessible via secret link" : "Privat – kun tilgjengelig via hemmelig lenke",
     "Update" : "Oppdater",
+    "(copy)" : "(kopier)",
     "Appointment name" : "Navn på avtale",
     "Location" : "Sted",
     "Create a Talk room" : "Opprett et Talk-rom",
@@ -313,6 +314,7 @@ OC.L10N.register(
     "Accept" : "Aksepter",
     "Decline" : "Avslå",
     "Tentative" : "Foreløpig",
+    "Copied to clipboard" : "Kopiert til utklippstavlen",
     "No attendees yet" : "Ingen deltakere enda",
     "Attendees" : "Deltakere",
     "Remove group" : "Fjern gruppe",
@@ -428,7 +430,6 @@ OC.L10N.register(
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Din konfigurerte tidssone ({timezoneId}) ble ikke funnet. Faller tilbake til UTC.\nVennligst endre tidssonen din i innstillingene og rapporter dette problemet.",
     "Edit event" : "Rediger hendelse",
     "Event does not exist" : "Hendelsen finnes ikke",
-    "Duplicate" : "Duplikat",
     "Delete this occurrence" : "Slett denne hendelsen",
     "Delete this and all future" : "Slett denne og fremtidige hendelser",
     "All day" : "Hele dagen",
@@ -535,6 +536,7 @@ OC.L10N.register(
     "Error while parsing a PROPFIND error" : "Feil under analyse av en PROPFIND-feil",
     "Appointment not found" : "Avtale ikke funnet",
     "User not found" : "Fant ikke brukeren",
+    "%1$s - %2$s" : "%1$s - %2$s",
     "Hidden" : "Skjult",
     "can edit" : "kan endre",
     "Calendar name …" : "Kalendernavn…",
