@@ -21,7 +21,6 @@ OC.L10N.register(
     "Appointments" : "Sestanki",
     "Schedule appointment \"%s\"" : "Načrtovanje sestanka »%s«",
     "Schedule an appointment" : "Načrtovanje sestanka",
-    "%1$s - %2$s" : "%1$s – %2$s",
     "Prepare for %s" : "Pripravi za %s",
     "Follow up for %s" : "Nadaljevanje za %s",
     "Your appointment \"%s\" with %s needs confirmation" : "Sestanek »%s« z osebo %s zahteva potrditev",
@@ -61,6 +60,7 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "Povezave sestanka ni mogoče kopirati v odložišče.",
     "Preview" : "Predogled",
     "Copy link" : "Kopiraj povezavo",
+    "Duplicate" : "Podvoji",
     "Edit" : "Uredi",
     "Delete" : "Izbriši",
     "Create new" : "Ustvari novo",
@@ -184,15 +184,11 @@ OC.L10N.register(
     "Calendar settings" : "Nastavitve koledarja",
     "No reminder" : "Brez opomnika",
     "Failed to save default calendar" : "Shranjevanje privzetega koledarja je spodletelo",
-    "CalDAV link copied to clipboard." : "Povezava CalDAV je kopirana v odložišče.",
-    "CalDAV link could not be copied to clipboard." : "Povezave CalDAV ni mogoče kopirati v odložišče.",
     "General" : "Splošno",
-    "Copy iOS/macOS CalDAV address" : "Kopiraj naslov CalDAV za iOS/macOS",
     "Appearance" : "Videz",
     "Editing" : "Urejanje",
-    "Default calendar for incoming invitations" : "Privzeti koledar za prihajajoča povabila",
     "Default reminder" : "Privzeti opomnik",
-    "Keyboard shortcuts" : "Tipkovne bližnjice",
+    "Files" : "Datoteke",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minuta","{duration} minuti","{duration} minute","{duration} minut"],
     "0 minutes" : "0 minut",
     "_{duration} hour_::_{duration} hours_" : ["{duration} ura","{duration} uri","{duration} ure","{duration} ur"],
@@ -204,6 +200,7 @@ OC.L10N.register(
     "Public – shown on the profile page" : "Javno – prikazano na strani profila",
     "Private – only accessible via secret link" : "Zasebno – dostopno le z zasebno povezavo",
     "Update" : "Posodobi",
+    "(copy)" : "(kopija)",
     "Appointment name" : "Ime srečanja",
     "Location" : "Mesto",
     "Create a Talk room" : "Ustvari skupino Talk",
@@ -308,9 +305,8 @@ OC.L10N.register(
     "Accept" : "Sprejmi",
     "Decline" : "Zavrni",
     "Tentative" : "V usklajevanju",
+    "Copied to clipboard" : "Kopirano v odložišče",
     "No attendees yet" : "Ni še vpisanih udeležencev",
-    "Successfully appended link to talk room to description." : "Povezava do sobe Talk je uspešno dodana v opis.",
-    "Error creating Talk room" : "Prišlo je do napake med ustvarjanjem klepetalnice Talk",
     "Attendees" : "Udeleženci",
     "Remove group" : "Odstrani skupino",
     "Remove attendee" : "Odstrani udeleženca",
@@ -418,7 +414,6 @@ OC.L10N.register(
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Nastavljenega časovnega pasu ({timezoneId}) ni mogoče najti. Povrnjena bo nastavitev na UTC.\nČasovni pas določite ročno med nastavitvami koledarja in pošljite poročilo o napaki.",
     "Edit event" : "Uredi dogodek",
     "Event does not exist" : "Dogodek ne obstaja",
-    "Duplicate" : "Podvoji",
     "Delete this occurrence" : "Izbriši to pojavitev",
     "Delete this and all future" : "Izbriši to in vse prihodnje pojavitve",
     "All day" : "Ves dan",
@@ -521,12 +516,15 @@ OC.L10N.register(
     "This is an event reminder." : "To je opomnik dogodka.",
     "Appointment not found" : "Sestanka ni mogoče najti",
     "User not found" : "Uporabnika ni mogoče najti",
+    "%1$s - %2$s" : "%1$s – %2$s",
     "Hidden" : "Skrito",
     "can edit" : "lahko ureja",
     "Calendar name …" : "Ime koledarja …",
     "Default attachments location" : "Privzeto mesto prilog",
     "Automatic ({detected})" : "Samodejno ({detected})",
     "Shortcut overview" : "Pregled tipkovnih bližnjic",
+    "CalDAV link copied to clipboard." : "Povezava CalDAV je kopirana v odložišče.",
+    "CalDAV link could not be copied to clipboard." : "Povezave CalDAV ni mogoče kopirati v odložišče.",
     "Enable birthday calendar" : "Omogoči koledar rojstnih dni",
     "Show tasks in calendar" : "Pokaži naloge v koledarju",
     "Enable simplified editor" : "Omogoči poenostavljen urejevalnik",
@@ -534,9 +532,13 @@ OC.L10N.register(
     "Show weekends" : "Pokaži vikende",
     "Show week numbers" : "Pokaži številke tednov",
     "Time increments" : "Časovno povečevanje",
+    "Default calendar for incoming invitations" : "Privzeti koledar za prihajajoča povabila",
     "Copy primary CalDAV address" : "Kopiraj osnovni naslov CalDAV",
+    "Copy iOS/macOS CalDAV address" : "Kopiraj naslov CalDAV za iOS/macOS",
     "Personal availability settings" : "Nastavitve osebne dejavnosti",
     "Show keyboard shortcuts" : "Pokaži tipkovne bližnjice",
+    "Successfully appended link to talk room to description." : "Povezava do sobe Talk je uspešno dodana v opis.",
+    "Error creating Talk room" : "Prišlo je do napake med ustvarjanjem klepetalnice Talk",
     "The visibility of this event in shared calendars." : "Vidnost tega dogodka v koledarjih v souporabi."
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
